@@ -272,7 +272,7 @@ void LegendVisitor::build() {
         legend->setFont(font);
         legend->setText(text);
         legend->setAngle((orientation_ / 180.) * 3.14);
-        (*legend).setVerticalAlign(orientation_ ? MBOTTOM : MHALF);
+        (*legend).setVerticalAlign(orientation_ ? VerticalAlign::BOTTOM : VerticalAlign::HALF);
 
         if (text == "ignore")
             continue;
@@ -306,8 +306,8 @@ void LegendVisitor::horizontal() {
     legend_->setCoordinates(0, nb * 2, rows + 1, 0);
 
     if (title_) {
-        if (title_position_ == M_AUTOMATIC)
-            title_position_ = M_TOP;
+        if (title_position_ == Position::AUTOMATIC)
+            title_position_ = Position::TOP;
         (this->*titleBuilders_[title_position_])();
     }
 
@@ -346,8 +346,8 @@ void LegendVisitor::vertical() {
 
     legend_->setCoordinates(0, nb, 0.5, rows + 0.5);
     if (title_) {
-        if (title_position_ == M_AUTOMATIC)
-            title_position_ = M_LEFT;
+        if (title_position_ == Position::AUTOMATIC)
+            title_position_ = Position::LEFT;
         (this->*titleBuilders_[title_position_])();
     }
 
@@ -371,7 +371,7 @@ void LegendVisitor::topTitle() {
     double height  = (100 / (100 - title_ratio_)) * (maxy - miny);
     double newmaxy = miny + height;
 
-    titleJustification_ = MCENTRE;
+    titleJustification_ = Justification::CENTRE;
     titleAngle_         = 0;
     titlePosition_      = PaperPoint((maxx - minx) / 2, (newmaxy + maxy) / 2);
 
@@ -388,7 +388,7 @@ void LegendVisitor::bottomTitle() {
 
     titlePosition_      = PaperPoint((maxx - minx) / 2, (newminy + miny) / 2);
     titleAngle_         = 0;
-    titleJustification_ = MCENTRE;
+    titleJustification_ = Justification::CENTRE;
 
     legend_->minY(newminy);
 }
@@ -406,9 +406,9 @@ void LegendVisitor::rightTitle() {
     float factor = column ? 0.25 : 0.15;
     // Special adjustement for the web ( PDF creation)
     // titlePosition_ = Paperoint(maxx+ (newmaxx-maxx)*factor, (maxy - miny)/2);
-    // titleJustification_ = ( column ) ?  MCENTRE : MRIGHT;
+    // titleJustification_ = ( column ) ?  Justification::CENTRE : Justification::RIGHT;
     titlePosition_      = PaperPoint(maxx + (newmaxx - maxx) * factor, (maxy + 3 * miny) / 4);
-    titleJustification_ = MLEFT;
+    titleJustification_ = Justification::LEFT;
 
     legend_->maxX(newmaxx);
 }
@@ -420,7 +420,7 @@ void LegendVisitor::leftTitle() {
 
     bool column = (legend_->absoluteWidth() < legend_->absoluteHeight());
 
-    titleJustification_ = (column) ? MCENTRE : MRIGHT;
+    titleJustification_ = (column) ? Justification::CENTRE : Justification::RIGHT;
     float factor        = (column) ? 0.25 : 0.15;
     titleAngle_         = (column) ? magics::PI * 1.5 : 0;
 
@@ -438,10 +438,10 @@ void LegendVisitor::grid() {
     }
 
     if (titleBuilders_.empty()) {
-        titleBuilders_[M_TOP]    = &LegendVisitor::topTitle;
-        titleBuilders_[M_BOTTOM] = &LegendVisitor::bottomTitle;
-        titleBuilders_[M_LEFT]   = &LegendVisitor::leftTitle;
-        titleBuilders_[M_RIGHT]  = &LegendVisitor::rightTitle;
+        titleBuilders_[Position::TOP]    = &LegendVisitor::topTitle;
+        titleBuilders_[Position::BOTTOM] = &LegendVisitor::bottomTitle;
+        titleBuilders_[Position::LEFT]   = &LegendVisitor::leftTitle;
+        titleBuilders_[Position::RIGHT]  = &LegendVisitor::rightTitle;
     }
 
     if (magCompare(direction_, "automatic")) {
@@ -562,7 +562,7 @@ void ArrowEntry::rowBox(const PaperPoint& point, BasicGraphicsObjectContainer& l
     Text* text = new Text();
     text->addText(label_, font_);
     text->push_back(leftTextBox(point));
-    text->setJustification(MLEFT);
+    text->setJustification(Justification::LEFT);
     legend.push_back(text);
     LegendVisitor::addLegendInfo("legend_entry_text", label_);
     LegendVisitor::addLegendInfo("legend_entry_type", "arrow");
@@ -577,7 +577,7 @@ void ArrowEntry::columnBox(const PaperPoint& point, BasicGraphicsObjectContainer
     Text* text = new Text();
     text->addText(label_, font_);
     text->push_back(pos);
-    text->setJustification(MLEFT);
+    text->setJustification(Justification::LEFT);
     legend.push_back(text);
 
     pos.y_ -= 0.2;
@@ -586,7 +586,6 @@ void ArrowEntry::columnBox(const PaperPoint& point, BasicGraphicsObjectContainer
     LegendVisitor::addLegendInfo("legend_entry_text", label_);
     LegendVisitor::addLegendInfo("legend_entry_type", "arrow");
     LegendVisitor::addLegendInfo("legend_entry_colour", arrow_->getColour().name());
-    
 }
 
 void FlagEntry::set(const PaperPoint& point, BasicGraphicsObjectContainer& legend) {
@@ -608,7 +607,7 @@ void FlagEntry::rowBox(const PaperPoint& point, BasicGraphicsObjectContainer& le
     Text* text = new Text();
     text->addText(label_, font_);
     text->push_back(leftTextBox(point));
-    text->setJustification(MLEFT);
+    text->setJustification(Justification::LEFT);
     legend.push_back(text);
     LegendVisitor::addLegendInfo("legend_entry_text", label_);
     LegendVisitor::addLegendInfo("legend_entry_type", "flag");
@@ -624,7 +623,7 @@ void FlagEntry::columnBox(const PaperPoint& point, BasicGraphicsObjectContainer&
     Text* text = new Text();
     text->addText(label_, font_);
     text->push_back(pos);
-    text->setJustification(MLEFT);
+    text->setJustification(Justification::LEFT);
     legend.push_back(text);
 
     LegendVisitor::addLegendInfo("legend_entry_text", label_);
@@ -701,9 +700,9 @@ void LegendEntry::columnBox(const PaperPoint& point, BasicGraphicsObjectContaine
 
     Text* from = new Text();
     Text* to   = new Text();
-    from->setVerticalAlign(MHALF);
+    from->setVerticalAlign(VerticalAlign::HALF);
 
-    to->setVerticalAlign(MHALF);
+    to->setVerticalAlign(VerticalAlign::HALF);
     from->addText(top.str(), font_);
 
     to->addText(bottom.str(), font_);
@@ -750,7 +749,7 @@ void BoxEntry::rowBox(const PaperPoint& point, BasicGraphicsObjectContainer& leg
     if (text_) {
         Text* from = new Text();
         from->push_back(PaperPoint(x - width, y - height - 0.25));
-        from->setVerticalAlign(MBOTTOM);
+        from->setVerticalAlign(VerticalAlign::BOTTOM);
         from->setAngle(angle_);
         legend.push_back(from);
 
@@ -774,7 +773,7 @@ void BoxEntry::rowBox(const PaperPoint& point, BasicGraphicsObjectContainer& leg
     if (last_) {
         Text* to = new Text();
         to->setAngle(angle_);
-        to->setVerticalAlign(MBOTTOM);
+        to->setVerticalAlign(VerticalAlign::BOTTOM);
         to->push_back(PaperPoint(x + width, y - height - 0.25));
         legend.push_back(to);
         if (automatic_) {
@@ -864,7 +863,7 @@ void BoxEntry::rowHisto(const PaperPoint& point, BasicGraphicsObjectContainer& l
     if (text_) {
         Text* from = new Text();
         from->push_back(PaperPoint(x - width, y + 1.3));
-        from->setVerticalAlign(MTOP);
+        from->setVerticalAlign(VerticalAlign::TOP);
         from->setAngle(angle_);
         legend.push_back(from);
 
@@ -876,7 +875,7 @@ void BoxEntry::rowHisto(const PaperPoint& point, BasicGraphicsObjectContainer& l
         else
             from->addText(userText_, font_);
         Polyline* tick = new Polyline();
-        tick->setLineStyle(M_SOLID);
+        tick->setLineStyle(LineStyle::SOLID);
         tick->setColour(Colour("black"));
         tick->push_back(PaperPoint(x - width, y + 1.1));
         tick->push_back(PaperPoint(x - width, y + 0.85));
@@ -885,7 +884,7 @@ void BoxEntry::rowHisto(const PaperPoint& point, BasicGraphicsObjectContainer& l
     if (last_) {
         Text* to = new Text();
         to->setAngle(angle_);
-        to->setVerticalAlign(MTOP);
+        to->setVerticalAlign(VerticalAlign::TOP);
         to->push_back(PaperPoint(x + width, y + 1.3));
         legend.push_back(to);
         if (automatic_) {
@@ -904,7 +903,7 @@ void BoxEntry::rowHisto(const PaperPoint& point, BasicGraphicsObjectContainer& l
         axe->push_back(PaperPoint(x + width, y + 0.8));
         legend.push_back(axe);
         Polyline* tick = new Polyline();
-        tick->setLineStyle(M_SOLID);
+        tick->setLineStyle(LineStyle::SOLID);
         tick->setColour(Colour("black"));
         tick->push_back(PaperPoint(x + width, y + 1.1));
         tick->push_back(PaperPoint(x + width, y + 0.85));
@@ -913,8 +912,8 @@ void BoxEntry::rowHisto(const PaperPoint& point, BasicGraphicsObjectContainer& l
     if (first_) {
         Text* to = new Text();
         to->setAngle(angle_);
-        to->setVerticalAlign(MBOTTOM);
-        to->setJustification(MRIGHT);
+        to->setVerticalAlign(VerticalAlign::BOTTOM);
+        to->setJustification(Justification::RIGHT);
         to->push_back(PaperPoint(x - width, y - 0.2));
         legend.push_back(to);
         if (userText_.empty() && histogram_->max() && automatic_) {
@@ -976,7 +975,7 @@ void BoxEntry::rowHisto(const PaperPoint& point, BasicGraphicsObjectContainer& l
 
     Polyline* topline = new Polyline();
     topline->setColour(box_->getFillColour());
-    topline->setLineStyle(M_DASH);
+    topline->setLineStyle(LineStyle::DASH);
     topline->push_back(PaperPoint(x - width, y - 0.2));
     topline->push_back(PaperPoint(x + width, y - 0.2));
 
@@ -1018,8 +1017,8 @@ void BoxEntry::columnBox(const PaperPoint& point, BasicGraphicsObjectContainer&
 
     if (text_) {
         Text* from = new Text();
-        from->setJustification(MLEFT);
-        from->setVerticalAlign(MHALF);
+        from->setJustification(Justification::LEFT);
+        from->setVerticalAlign(VerticalAlign::HALF);
         if (automatic_) {
             if (!userMin_) {
                 ostringstream bottom;
@@ -1046,8 +1045,8 @@ void BoxEntry::columnBox(const PaperPoint& point, BasicGraphicsObjectContainer&
     }
     if (last_) {
         Text* to = new Text();
-        to->setVerticalAlign(MHALF);
-        to->setJustification(MLEFT);
+        to->setVerticalAlign(VerticalAlign::HALF);
+        to->setJustification(Justification::LEFT);
         to->setAngle(angle_);
 
         if (automatic_) {
@@ -1127,8 +1126,8 @@ void BoxEntry::columnHisto(const PaperPoint& point, BasicGraphicsObjectContainer
 
     if (text_) {
         Text* from = new Text();
-        from->setJustification(MLEFT);
-        from->setVerticalAlign(MHALF);
+        from->setJustification(Justification::LEFT);
+        from->setVerticalAlign(VerticalAlign::HALF);
         if (userText_.empty() || last_) {
             ostringstream bottom;
             bottom << MagicsFormat(format_, from_);
@@ -1144,8 +1143,8 @@ void BoxEntry::columnHisto(const PaperPoint& point, BasicGraphicsObjectContainer
     }
     if (last_) {
         Text* to = new Text();
-        to->setVerticalAlign(MHALF);
-        to->setJustification(MLEFT);
+        to->setVerticalAlign(VerticalAlign::HALF);
+        to->setJustification(Justification::LEFT);
         to->setAngle(angle_);
         if (userText_.empty()) {
             ostringstream top, bottom;
@@ -1400,7 +1399,7 @@ void SimpleSymbolEntry::rowBox(const PaperPoint& point, BasicGraphicsObjectConta
     if (text_) {
         Text* from = new Text();
         from->push_back(PaperPoint(x - width, y - height - 0.25));
-        from->setVerticalAlign(MBOTTOM);
+        from->setVerticalAlign(VerticalAlign::BOTTOM);
         from->setAngle(angle_);
         legend.push_back(from);
         if (userText_.empty() || last_) {
@@ -1414,7 +1413,7 @@ void SimpleSymbolEntry::rowBox(const PaperPoint& point, BasicGraphicsObjectConta
     if (last_) {
         Text* to = new Text();
         to->setAngle(angle_);
-        to->setVerticalAlign(MBOTTOM);
+        to->setVerticalAlign(VerticalAlign::BOTTOM);
         to->push_back(PaperPoint(x + width, y - height - 0.25));
         legend.push_back(to);
         if (userText_.empty()) {
@@ -1458,8 +1457,8 @@ void SimpleSymbolEntry::columnBox(const PaperPoint& point, BasicGraphicsObjectCo
 
     if (text_) {
         Text* from = new Text();
-        from->setJustification(MLEFT);
-        from->setVerticalAlign(MHALF);
+        from->setJustification(Justification::LEFT);
+        from->setVerticalAlign(VerticalAlign::HALF);
         if (userText_.empty() || last_) {
             ostringstream bottom;
             bottom << MagicsFormat(format_, from_);
@@ -1475,8 +1474,8 @@ void SimpleSymbolEntry::columnBox(const PaperPoint& point, BasicGraphicsObjectCo
     }
     if (last_) {
         Text* to = new Text();
-        to->setVerticalAlign(MHALF);
-        to->setJustification(MLEFT);
+        to->setVerticalAlign(VerticalAlign::HALF);
+        to->setJustification(Justification::LEFT);
         to->setAngle(angle_);
         if (userText_.empty()) {
             ostringstream top, bottom;
@@ -1514,7 +1513,6 @@ void LegendVisitor::visit(MetaDataVisitor& visitor) {
     }
 
 
-
     out << c1 << "\"legend_entries\" : [";
     c1 = "";
     for (auto& entry : legendEntriesInfo_) {
