@@ -40,7 +40,7 @@ public:
 
 protected:
     //! Method to print string about this class on to a stream of type ostream (virtual).
-    virtual void print(ostream&) const {}
+    virtual void print(ostream& s) const { s << "ColourTableDefinitionComputeInterface[]"; }
 
 private:
     //! Copy constructor - No copy allowed
