@@ -28,8 +28,8 @@
 #include "BinningObject.h"
 #include "CustomisedPoint.h"
 #include "DataStats.h"
-#include "MagDateTime.h"
 #include "Layer.h"
+#include "MagDateTime.h"
 #include "MagicsEvent.h"
 #include "MatrixHandler.h"
 #include "PointsHandler.h"
@@ -57,7 +57,7 @@ public:
 class Data : public MetviewIcon {
 public:
     Data() : dimension_(1), valid_(true), thinningFactor_(1), name_("no_name"), binning_(0) {}
-    virtual ~Data() {
+    virtual ~Data() override {
         if (binning_)
             delete binning_;
     }
@@ -68,6 +68,9 @@ public:
     virtual MatrixHandler& direction() { throw MethodNotYetImplemented("Data::norm"); }
     void binning(BinningObject* binning) { binning_ = binning; }
 
+    virtual Data* current() { return this; }
+    virtual Data* next() { return 0; }
+
 
     virtual void release() {}
 
@@ -116,13 +119,13 @@ public:
     virtual void visit(AnimationRules&) {}
     virtual void visit(AnimationStep&) {}
     virtual void visit(MetaDataVisitor&) {}
-    virtual void visit(Layer& layer) {
+    virtual void visit(Layer& layer) override {
         MetviewIcon::visit(layer);
         layer.name(name());
         layer.validTime(from(), to());
     }
     bool valid() { return valid_; }
-    virtual void visit(MetaDataCollector& collector) { MetviewIcon::visit(collector); }
+    virtual void visit(MetaDataCollector& collector) override { MetviewIcon::visit(collector); }
     virtual void visit(ValuesCollector&) {}
     virtual void visit(DataIndexCollector& dc) { dc.setDataIndex(dataIndex_); }
     virtual void visit(MagnifierCollector& magnifier) {
@@ -135,9 +138,11 @@ public:
             list.advance();
         }
     }
-    virtual void initInfo() { MetviewIcon::initInfo(); }
+    virtual void initInfo() override { MetviewIcon::initInfo(); }
     string legend() { return legend_; }
 
+    virtual std::string getUnits() const;
+
     // Information needed fron layer management!
     virtual string layerId() { return (layerId_.empty()) ? iconName_ + "/ " + iconClass_ : layerId_; }
     virtual string name() { return (iconName_.empty()) ? name_ : iconName_; }
@@ -165,7 +170,7 @@ protected:
     LevelDescription dataLevel_;
 
     //! Method to print string about this class on to a stream of type ostream (virtual).
-    virtual void print(ostream& out) const { out << "Data<P>"; }
+    virtual void print(ostream& out) const override { out << "Data<P>"; }
     virtual void computeStats();
 
     AutoVector<PointsHandler> pointsHandlers_;
@@ -202,7 +207,7 @@ private:
 class DataLoop : public MetviewIcon {
 public:
     DataLoop() {}
-    virtual ~DataLoop() {}
+    virtual ~DataLoop() override {}
     virtual void set(const map<string, string>&) {}
     virtual void set(const XmlNode&) {}
     virtual void set(LayerNode&) {}
@@ -215,18 +220,18 @@ public:
     virtual string layerId() { return iconName_ + "/ " + iconClass_; }
     virtual string name() { return iconName_; }
     virtual void visit(Transformation&) {}
-    void visit(Layer& layer) { MetviewIcon::visit(layer); }
+    void visit(Layer& layer) override { MetviewIcon::visit(layer); }
 };
 
 class DataList : public DataLoop {
 public:
     DataList();
-    ~DataList();
-    void setToFirst();
-    Data* current();
-    bool hasMore();
-    void next();
-    void add(Data*);
+    ~DataList() override;
+    void setToFirst() override;
+    Data* current() override;
+    bool hasMore() override;
+    void next() override;
+    void add(Data*) override;
 
 protected:
     vector<Data*>::iterator current_;
