@@ -41,7 +41,7 @@ public:
 
 protected:
     //! Method to print string about this class on to a stream of type ostream (virtual).
-    virtual void print(ostream& out) const { out << "Dimension"; }
+    virtual void print(ostream& out) const { out << "Dimension[]"; }
     double absolute_;
     double percent_;
     int pixel_;
