@@ -1,45 +1,38 @@
 /*
  * (C) Copyright 1996-2016 ECMWF.
- * 
+ *
  * This software is licensed under the terms of the Apache Licence Version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
- * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
 /*! \file FrameBase.cc
     \brief Implementation of the Template class FrameBase.
-    
-    Magics Team - ECMWF 2006
-    
-    Started: Thu 9-Feb-2006
-    
-    Changes:
-    
-*/
 
+    Magics Team - ECMWF 2006
+
+    Started: Thu 9-Feb-2006
+
+    Changes:
+
+*/
 
 
 #include "FrameBase.h"
 
 using namespace magics;
 
-FrameBase::FrameBase() 
-{
-}
+FrameBase::FrameBase() {}
 
 
-FrameBase::~FrameBase() 
-{
-}
+FrameBase::~FrameBase() {}
 
 /*!
  Class information are given to the output-stream.
-*/		
-void FrameBase::print(ostream& out)  const
-{
-	out << "FrameBase[";
-	out << "]";
+*/
+void FrameBase::print(ostream& out) const {
+    out << "FrameBase[";
+    out << "]";
 }
-
