@@ -47,7 +47,7 @@ Layout::Layout() :
     height_(100),
     x_(0),
     y_(0),
-    display_(M_DT_INLINE),
+    display_(DisplayType::INLINE),
     xmin_(0),
     xmax_(100),
     ymin_(0),
@@ -119,7 +119,8 @@ MagnifierLayout::~MagnifierLayout() {}
 MagnifierLayout::MagnifierLayout() {}
 
 
-LayoutFrame::LayoutFrame() : thickness_(1), style_(M_SOLID), colour_("grey"), blanking_(false), visible_(false) {}
+LayoutFrame::LayoutFrame() :
+    thickness_(1), style_(LineStyle::SOLID), colour_("grey"), blanking_(false), visible_(false) {}
 
 LayoutFrame::~LayoutFrame() {}
 
@@ -415,5 +416,9 @@ bool BasicLayout::buildTree(const Layout& parent, unsigned int frame, const Base
     return more;
 }
 
+string Layout::infoTransformation() const { 
+    return transformation_ ? transformation_->name() : "";
+}
+
 
 vector<DriverInfo> Layout::driverInfos_;
