@@ -22,7 +22,9 @@
 #include "MetaData.h"
 #include "Timer.h"
 
-#ifndef MAGICS_ON_WINDOWS
+#ifdef MAGICS_ON_WINDOWS
+#include "windux.h"
+#else
 #include <sys/resource.h>
 #include <sys/time.h>
 #endif
@@ -91,6 +93,9 @@ void MetaDataVisitor::collectMetaData() {
     }
 
     catch (...) {
+        if (MagicsGlobal::strict()) {
+            throw;
+        }
     }
 
     if (!wms_file_.empty() && styles_.size()) {
@@ -104,6 +109,9 @@ void MetaDataVisitor::collectMetaData() {
             out.close();
         }
         catch (...) {
+            if (MagicsGlobal::strict()) {
+                throw;
+            }
         }
     }
     if (!javascript_.empty()) {
@@ -126,6 +134,9 @@ void MetaDataVisitor::collectMetaData() {
             out.close();
         }
         catch (...) {
+            if (MagicsGlobal::strict()) {
+                throw;
+            }
         }
     }
 
@@ -149,6 +160,9 @@ void MetaDataVisitor::collectMetaData() {
             out.close();
         }
         catch (...) {
+            if (MagicsGlobal::strict()) {
+                throw;
+            }
         }
     }
 
@@ -167,11 +181,14 @@ void MetaDataVisitor::collectMetaData() {
             out.close();
         }
         catch (...) {
+            if (MagicsGlobal::strict()) {
+                throw;
+            }
         }
     }
     if (!efi_.empty()) {
         char c;
-        string path = buildConfigPath("efi", efi_template_);
+        string path = buildSharePath("efi", efi_template_);
         try {
             ofstream out(efi_.c_str());
             ifstream in(path.c_str());
@@ -184,6 +201,9 @@ void MetaDataVisitor::collectMetaData() {
             ofstream out(efi_.c_str());
             out << " Could not opened " << path << endl;
             out.close();
+            if (MagicsGlobal::strict()) {
+                throw;
+            }
         }
     }
 }
