@@ -80,14 +80,14 @@ private:
 class GribAddressRecordMode : public GribAddressMode {
 public:
     GribAddressRecordMode() {}
-    ~GribAddressRecordMode() {}
+    ~GribAddressRecordMode() override {}
 
-    virtual GribAddressMode* clone() const {
+    virtual GribAddressMode* clone() const override {
         GribAddressMode* mode = new GribAddressRecordMode();
         return mode;
     }
 
-    virtual grib_handle* operator()(grib_context*, FILE* file, int position) const {
+    virtual grib_handle* operator()(grib_context*, FILE* file, int position) const override {
         grib_handle* handle = 0;
 
 
@@ -107,20 +107,20 @@ public:
     }
 
 protected:
-    void print(ostream& out) const { out << "GribAddressRecordMode\n"; }
+    void print(ostream& out) const override { out << "GribAddressRecordMode[]"; }
 };
 
 class GribAddressByteMode : public GribAddressMode {
 public:
     GribAddressByteMode() {}
-    ~GribAddressByteMode() {}
-    virtual GribAddressMode* clone() const {
+    ~GribAddressByteMode() override {}
+    virtual GribAddressMode* clone() const override {
         GribAddressMode* mode = new GribAddressByteMode();
         return mode;
     }
 
-    virtual grib_handle* operator()(grib_context* context, FILE* file, int position) const {
-        long int offset = (long int)position;
+    virtual grib_handle* operator()(grib_context* context, FILE* file, int position) const override {
+        // long int offset = (long int)position;
         // cout << "OFFSET-->" << offset << endl;
         fseek(file, (long int)position, SEEK_SET);
         grib_handle* handle = 0;
@@ -130,7 +130,7 @@ public:
 
         return handle;
     }
-    virtual grib_handle* operator()(grib_context* context, FILE* file, long int position) const {
+    virtual grib_handle* operator()(grib_context* context, FILE* file, long int position) const override {
         fseek(file, position, SEEK_SET);
         grib_handle* handle = 0;
 
@@ -141,7 +141,7 @@ public:
     }
 
 protected:
-    void print(ostream& out) const { out << "GribAddressRecordMode\n"; }
+    void print(ostream& out) const override { out << "GribAddressRecordMode\n"; }
 };
 
 
