@@ -47,8 +47,8 @@ public:
 
 class NoSuchNetcdfFile : public MagicsException {
 public:
-    NoSuchNetcdfFile(const string& file) :
-        MagicsException("Netcdf MagException: The file " + file + " does not exist or is not a valid netcdf file") {
+    NoSuchNetcdfFile(const string& file, const string& why) :
+        MagicsException("Netcdf MagException: Cannot open " + file + ": " + why) {
         MagLog::error() << what() << "\n";
     }
 };
@@ -387,7 +387,7 @@ public:
 
     double getMissing(const string&, const string&);
 
-    string detect(const string& var, const string& type) const;
+    string detect(const string& var, const string& type, bool use_cache = true) const;
 
 
     template <class T>
@@ -485,6 +485,7 @@ protected:
     map<string, NetVariable> dataset_;
     map<string, NetAttribute> attributes_;
     double missing_;
+    mutable map<string, string> detected_;
 
 private:
     int file_;
