@@ -37,13 +37,13 @@ NetcdfGeopointsInterpretor::~NetcdfGeopointsInterpretor() {}
 
 static void setDim(Netcdf& netcdf, const string& name, vector<double>& values, map<string, string>& first,
                    map<string, string>& last) {
-       
+
     try {
-       
+
         netcdf.get(name, values, first, last);
-       
+
     }
-    catch (exception& e) {    
+    catch (exception& e) {
         int dim = netcdf.getDimension(name);
         for (int i = 0; i < dim; ++i)
             values.push_back(i);
@@ -97,6 +97,9 @@ bool NetcdfGeopointsInterpretor::interpretAsPoints(PointsList& list, const Trans
         }
     }
     catch (MagicsException& e) {
+        if (MagicsGlobal::strict()) {
+            throw;
+        }
         MagLog::error() << e << "\n";
         return false;
     }
@@ -148,6 +151,9 @@ bool NetcdfGeopointsInterpretor::interpretAsPoints(PointsList& list) {
         }
     }
     catch (MagicsException& e) {
+        if (MagicsGlobal::strict()) {
+            throw;
+        }
         MagLog::error() << e << "\n";
         return false;
     }
@@ -271,6 +277,9 @@ bool NetcdfXYpointsInterpretor::interpretAsPoints(PointsList& list, const Transf
         }
     }
     catch (MagicsException& e) {
+        if (MagicsGlobal::strict()) {
+            throw;
+        }
         MagLog::error() << e << "\n";
         return false;
     }
@@ -292,7 +301,7 @@ bool NetcdfXYpointsInterpretor::interpretAsPoints(PointsList& list, const std::s
         vector<double> values;
         map<string, string> first, last;
         setDimensions(dimension_, first, last);
-        
+
         if (field_.empty() == false) {
             netcdf.get(field_, values, first, last);
         }
@@ -311,7 +320,7 @@ bool NetcdfXYpointsInterpretor::interpretAsPoints(PointsList& list, const std::s
         vector<double>::const_iterator val = values.begin();
 
         while (x != xs.end() && y != ys.end()) {
-            
+
             double value = 0;
             if (val != values.end()) {
                 value = *val;
@@ -341,6 +350,9 @@ bool NetcdfXYpointsInterpretor::interpretAsPoints(PointsList& list, const std::s
         }
     }
     catch (MagicsException& e) {
+        if (MagicsGlobal::strict()) {
+            throw;
+        }
         MagLog::error() << e << "\n";
         return false;
     }
@@ -380,6 +392,9 @@ void NetcdfXYpointsInterpretor::visit(Transformation& transformation) {
         }
     }
     catch (...) {
+        if (MagicsGlobal::strict()) {
+            throw;
+        }
     }
 }
 
@@ -454,6 +469,9 @@ void NetcdfXYpointsInterpretor::visit(MetaDataCollector& mdc) {
             }
         }
         catch (...) {
+            if (MagicsGlobal::strict()) {
+                throw;
+            }
         }
 
         mdc["statsType"] = "scalar";
