@@ -25,6 +25,7 @@
 #include "Factory.h"
 #include "NetcdfData.h"
 #include "NetcdfVectorInterpretor.h"
+#include "MagicsGlobal.h"
 
 
 using namespace magics;
@@ -83,6 +84,9 @@ void NetcdfVectorInterpretor::customisedPoints(const Transformation& transformat
         }
     }
     catch (MagicsException& e) {
+        if (MagicsGlobal::strict()) {
+            throw;
+        }
         MagLog::error() << e << "\n";
     }
 }
@@ -136,6 +140,9 @@ void NetcdfGeoVectorInterpretor::customisedPoints(const Transformation& transfor
         }
     }
     catch (MagicsException& e) {
+        if (MagicsGlobal::strict()) {
+            throw;
+        }
         MagLog::error() << e << "\n";
     }
 }
@@ -235,6 +242,9 @@ void NetcdfGeoPolarMatrixInterpretor::customisedPoints(const Transformation&, co
         */
     }
     catch (MagicsException& e) {
+        if (MagicsGlobal::strict()) {
+            throw;
+        }
         MagLog::error() << e << "\n";
     }
 }
