@@ -37,25 +37,25 @@ class StyleEntry;
 class Contour : public ContourAttributes, public Visdef {
 public:
     Contour();
-    virtual ~Contour();
+    virtual ~Contour() override;
 
     virtual Contour* clone() const {
         Contour* contour = new Contour();
         contour->copy(*this);
         return contour;
     }
-    bool needLegend() { return legend_; }
+    bool needLegend() override { return legend_; }
     // Implements the set method ...
-    void set(const XmlNode& node) { ContourAttributes::set(node); }
-    void set(const map<string, string>& map) { ContourAttributes::set(map); }
+    void set(const XmlNode& node) override { ContourAttributes::set(node); }
+    void set(const map<string, string>& map) override { ContourAttributes::set(map); }
 
     // Implements the VisDefinterface
-    virtual void operator()(Data&, BasicGraphicsObjectContainer&);
-    virtual void visit(Data&, LegendVisitor&);
+    virtual void operator()(Data&, BasicGraphicsObjectContainer&) override;
+    virtual void visit(Data&, LegendVisitor&) override;
 
-    void visit(Data&, HistoVisitor&);
-    void visit(MetaDataVisitor&);
-    void getReady(const LegendVisitor& legend) {
+    void visit(Data&, HistoVisitor&) override;
+    void visit(MetaDataVisitor&) override;
+    void getReady(const LegendVisitor& legend) override {
         contour_->legend_only_ = legend.only_;
         legendIsOn_            = true;
     }
@@ -63,7 +63,7 @@ public:
 
 protected:
     //! Method to print string about this class on to a stream of type ostream (virtual).
-    virtual void print(ostream&) const;
+    virtual void print(ostream&) const override;
     MatrixHandler* matrix_;
     StyleEntry* styleInfo_;
     MagDef automaticAttributes_;
