@@ -11,9 +11,10 @@
 #include "ObsJSon.h"
 #include <locale>
 #include "CustomisedPoint.h"
+#include "MagParser.h"
+#include "MagicsGlobal.h"
 #include "MetaData.h"
 #include "Value.h"
-#include "JSONParser.h"
 
 using namespace magics;
 
@@ -33,14 +34,14 @@ CustomisedPoint* ObsJSon::decode(ValueMap& point) {
     CustomisedPoint* current = new CustomisedPoint();
     for (auto key = point.begin(); key != point.end(); ++key) {
         map<string, ObsJSon::Method>::iterator method = methods_.find(key->first);
-        
+
         if (method != methods_.end()) {
             (this->*method->second)(key->second, *current);
         }
         else {
-            
+
             if (key->second.isDouble()) {
-               
+
                 (*current)[key->first] = key->second.get_value<double>();
             }
         }
@@ -51,11 +52,12 @@ CustomisedPoint* ObsJSon::decode(ValueMap& point) {
 
 
 void ObsJSon::decode() {
-     
+
     points_.clear();
     Value value;
     if (!values_.empty()) {
         for (vector<string>::iterator val = values_.begin(); val != values_.end(); ++val) {
+            value = MagParser::decodeString(*val);
             ValueMap object = value.get_value<ValueMap>();
             points_.push_back(decode(object));
         }
@@ -63,16 +65,14 @@ void ObsJSon::decode() {
     }
 
     try {
-       
-        
-        Value value = JSONParser::decodeFile(path_);
+        Value value = MagParser::decodeFile(path_);
+
 
-        
 
         ValueMap object = value.get_value<ValueMap>();
 
         for (auto entry = object.begin(); entry != object.end(); ++entry) {
-            
+
             ValueList points = entry->second.get_value<ValueList>();
 
             for (unsigned int i = 0; i < points.size(); i++) {
@@ -82,6 +82,9 @@ void ObsJSon::decode() {
         }
     }
     catch (std::exception& e) {
+        if (MagicsGlobal::strict()) {
+            throw;
+        }
         MagLog::error() << "Could not processed the file: " << path_ << ": " << e.what() << endl;
     }
 }
